netapp_ontap.models.chassis_pcis_cards API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.chassis_pcis_cards`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class ChassisPcisCardsSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the ChassisPcisCards object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `device GET POST PATCH`

    The description of the PCI card.

    Example: Intel Lewisburg series chipset SATA Controller

  `info GET POST PATCH`

    The info string from the device driver of the PCI card.

    Example: Additional Info: 0 (0xaaf00000) SHM2S86Q120GLM22NP FW1146 114473MB 512B/sect (SPG190108GW)

  `slot GET POST PATCH`

    The slot where the PCI card is placed. This can sometimes take the form of "6-1" to indicate slot and subslot.

    Example: 0